==> haskell-lifted-async-0.10.2.7-113-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lifted-async
version:              0.10.2.7
visibility:           public
id:                   lifted-async-0.10.2.7-GrQDvhkJQEB1fPBk9NdQYD
key:                  lifted-async-0.10.2.7-GrQDvhkJQEB1fPBk9NdQYD
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2024 Mitsutoshi Aoe
maintainer:           Mitsutoshi Aoe <me@maoe.name>
author:               Mitsutoshi Aoe
homepage:             https://github.com/maoe/lifted-async
synopsis:
    Run lifted IO operations asynchronously and wait for their results

description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

category:             Concurrency
abi:                  70a999fc5378d315275f3492a5cb0b39
exposed:              True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lifted-async
hs-libraries:         HSlifted-async-0.10.2.7-GrQDvhkJQEB1fPBk9NdQYD
depends:
    async-2.2.5-8qrDbV8xcFXEsDmo0VTM7z base-4.17.2.1
    constraints-0.14.1-BfGp7Su1CXeJ9qTHFeoc6E
    lifted-base-0.2.3.12-CrE82teu6C0EM9A00pAiFN
    monad-control-1.0.3.1-3YyxfYDvjNjHqJQVD2Wq6U
    transformers-base-0.4.6-PXsczZ9bITEmXyp4AKCQa

haddock-interfaces:
    /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock

haddock-html:         /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-async-0.10.2.7-114-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lifted-async
version:              0.10.2.7
visibility:           public
id:                   lifted-async-0.10.2.7-7ylrekKnijhCwHLoKnMT52
key:                  lifted-async-0.10.2.7-7ylrekKnijhCwHLoKnMT52
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2024 Mitsutoshi Aoe
maintainer:           Mitsutoshi Aoe <me@maoe.name>
author:               Mitsutoshi Aoe
homepage:             https://github.com/maoe/lifted-async
synopsis:
    Run lifted IO operations asynchronously and wait for their results

description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

category:             Concurrency
abi:                  2f00af10688c4c6899e031e02322949e
exposed:              True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lifted-async
hs-libraries:         HSlifted-async-0.10.2.7-7ylrekKnijhCwHLoKnMT52
depends:
    async-2.2.5-IMWOwzxkt69JaaUstRte6Z base-4.17.2.1
    constraints-0.14.1-Ar3UdDS8ctq6zHPOOrKGVg
    lifted-base-0.2.3.12-FoXqbEZJR6orGW9DJoJmx
    monad-control-1.0.3.1-A4IAQIGkES44eARmeUYssL
    transformers-base-0.4.6-BxWaKKyao2EKzvnDCf8sIA

haddock-interfaces:
    /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock

haddock-html:         /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
